       function [D,z] = periodic_spectral_D2(z0,zL,n)
%...
%...  The MatMol Group (2009)
%...
%...  function periodic_spectral_D2 returns the differentiation matrix for computing 
%...  the second derivative, x_zz, of a variable x over the spatial domain [0,2pi)
%...  from a spectral method on a periodic grid
%...  This code is a slight adapatation of a code taken from (Trefethen, 2000)
%...
%...  argument list
%...
%...     z0      left value of the spatial independent variable (input)
%...
%...     zL      right value of the spatial independent variable (input)
%...
%...     n       even (!) number of spatial grid points
%...
%...     D       differentiation matrix (output)
%...
%...     z       points (output)
%...
%...  the program computes the first column and then uses the toeplitz command to 
%...  create the matrix.
%...
%... Reference
%...
%... Lloyd N. Trefethen
%... Spectral Methods in Matlab
%... SIAM, 2000
%...
%...  compute the spatial increment
        dz = 2*pi/n;
        z = [0:dz:2*pi-dz]';
%...
%...  discretization matrix      
       column = [-pi^2/(3*dz^2)-1/6 0.5*(-1).^(1:n-1).*csc((1:n-1)*dz/2).^2]';
       D = toeplitz(column,column([1 n:-1:2]));
%...      
       z = z0 + z*(zL-z0)/(2*pi);                  % convert to interval [z0, zL]
       D = D*(2*pi/(zL-z0))^2;
